🤝🤝🤝 Please star ⭐️ it for promoting open source projects 🌍 ! Thanks !

# Python package - KMMTransferReg 

A transfer learning regression model based on Kernel Mean Matching (KMM) algorithm

Written using Python, which is suitable for operating systems, e.g., Windows/Linux/MAC OS etc.


## Installing / 安装
    pip install KMMTR 
    
## Checking / 查看
    pip show KMMTR 
    
## Updating / 更新
    pip install --upgrade KMMTR


## References / 参考文献
Huang, J., Gretton, A., Borgwardt, K., Schölkopf, B., & Smola, A. (2006). Correcting sample selection bias by unlabeled data. Advances in neural information processing systems, 19.

## About / 更多
Maintained by Bin Cao. Please feel free to open issues in the Github or contact Bin Cao
(bcao@shu.edu.cn) in case of any problems/comments/suggestions in using the code. 


